@@ -3,19 +3,22 @@ import logging
 import sys
 import requests
 import os
-import process
+from .errors import WorkflowException
 import re
 import tempfile
+from typing import Any, Text, Union
 
 _logger = logging.getLogger("cwltool")
 
 def get_image(dockerRequirement, pull_image, dry_run=False):
+    # type: (Dict[Text, Text], bool, bool) -> bool
     found = False
 
     if "dockerImageId" not in dockerRequirement and "dockerPull" in dockerRequirement:
         dockerRequirement["dockerImageId"] = dockerRequirement["dockerPull"]
 
-    for ln in subprocess.check_output(["docker", "images", "--no-trunc", "--all"]).splitlines():
+    for ln in subprocess.check_output(
+            ["docker", "images", "--no-trunc", "--all"]).splitlines():
         try:
             m = re.match(r"^([^ ]+)\s+([^ ]+)\s+([^ ]+)", ln)
             sp = dockerRequirement["dockerImageId"].split(":")
@@ -29,32 +32,34 @@ def get_image(dockerRequirement, pull_image, dry_run=False):
             pass
 
     if not found and pull_image:
+        cmd = []  # type: List[str]
         if "dockerPull" in dockerRequirement:
-            cmd = ["docker", "pull", dockerRequirement["dockerPull"]]
-            _logger.info(str(cmd))
+            cmd = ["docker", "pull", str(dockerRequirement["dockerPull"])]
+            _logger.info(Text(cmd))
             if not dry_run:
                 subprocess.check_call(cmd, stdout=sys.stderr)
                 found = True
         elif "dockerFile" in dockerRequirement:
-            dockerfile_dir = tempfile.mkdtemp()
+            dockerfile_dir = str(tempfile.mkdtemp())
             with open(os.path.join(dockerfile_dir, "Dockerfile"), "w") as df:
                 df.write(dockerRequirement["dockerFile"])
-            cmd = ["docker", "build", "--tag=%s" % dockerRequirement["dockerImageId"], dockerfile_dir]
-            _logger.info(str(cmd))
+            cmd = ["docker", "build", "--tag=%s" %
+                str(dockerRequirement["dockerImageId"]), dockerfile_dir]
+            _logger.info(Text(cmd))
             if not dry_run:
                 subprocess.check_call(cmd, stdout=sys.stderr)
                 found = True
         elif "dockerLoad" in dockerRequirement:
             cmd = ["docker", "load"]
-            _logger.info(str(cmd))
+            _logger.info(Text(cmd))
             if not dry_run:
                 if os.path.exists(dockerRequirement["dockerLoad"]):
-                    _logger.info("Loading docker image from %s", dockerRequirement["dockerLoad"])
+                    _logger.info(u"Loading docker image from %s", dockerRequirement["dockerLoad"])
                     with open(dockerRequirement["dockerLoad"], "rb") as f:
                         loadproc = subprocess.Popen(cmd, stdin=f, stdout=sys.stderr)
                 else:
                     loadproc = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=sys.stderr)
-                    _logger.info("Sending GET request to %s", dockerRequirement["dockerLoad"])
+                    _logger.info(u"Sending GET request to %s", dockerRequirement["dockerLoad"])
                     req = requests.get(dockerRequirement["dockerLoad"], stream=True)
                     n = 0
                     for chunk in req.iter_content(1024*1024):
@@ -64,11 +69,12 @@ def get_image(dockerRequirement, pull_image, dry_run=False):
                     loadproc.stdin.close()
                 rcode = loadproc.wait()
                 if rcode != 0:
-                    raise process.WorkflowException("Docker load returned non-zero exit status %i" % (rcode))
+                    raise WorkflowException("Docker load returned non-zero exit status %i" % (rcode))
                 found = True
         elif "dockerImport" in dockerRequirement:
-            cmd = ["docker", "import", dockerRequirement["dockerImport"], dockerRequirement["dockerImageId"]]
-            _logger.info(str(cmd))
+            cmd = ["docker", "import", str(dockerRequirement["dockerImport"]),
+                str(dockerRequirement["dockerImageId"])]
+            _logger.info(Text(cmd))
             if not dry_run:
                 subprocess.check_call(cmd, stdout=sys.stderr)
                 found = True
@@ -77,18 +83,19 @@ def get_image(dockerRequirement, pull_image, dry_run=False):
 
 
 def get_from_requirements(r, req, pull_image, dry_run=False):
+    # type: (Dict[Text, Text], bool, bool, bool) -> Text
     if r:
         errmsg = None
         try:
             subprocess.check_output(["docker", "version"])
         except subprocess.CalledProcessError as e:
-            errmsg = "Cannot communicate with docker daemon: " + str(e)
+            errmsg = "Cannot communicate with docker daemon: " + Text(e)
         except OSError as e:
-            errmsg = "'docker' executable not found: " + str(e)
+            errmsg = "'docker' executable not found: " + Text(e)
 
         if errmsg:
             if req:
-                raise process.WorkflowException(errmsg)
+                raise WorkflowException(errmsg)
             else:
                 return None
 
@@ -96,6 +103,6 @@ def get_from_requirements(r, req, pull_image, dry_run=False):
             return r["dockerImageId"]
         else:
             if req:
-                raise process.WorkflowException("Docker image %s not found" % r["dockerImageId"])
+                raise WorkflowException(u"Docker image %s not found" % r["dockerImageId"])
 
     return None
